==> servux-neoforge-0.4.0%2Bmc1.21.3-sources.jar: fi/dy/masa/servux/settings/ServuxBoolSetting.java <==
package fi.dy.masa.servux.settings;

import com.google.gson.JsonElement;
import com.google.gson.JsonPrimitive;
import fi.dy.masa.servux.dataproviders.IDataProvider;
import net.minecraft.text.Text;

import java.util.List;

public class ServuxBoolSetting extends AbstractServuxSetting<Boolean>
{
    public ServuxBoolSetting(IDataProvider dataProvider, String name, Text prettyName, Text comment, boolean defaultValue)
    {
        super(dataProvider, name, prettyName, comment, defaultValue, List.of("true", "false"));
    }

    public ServuxBoolSetting(IDataProvider dataProvider, String name, boolean defaultValue)
    {
        super(dataProvider, name, null, null, defaultValue, List.of("true", "false"));
    }

    @Override
    public boolean validateString(String value)
    {
        return value.equalsIgnoreCase("true") || value.equalsIgnoreCase("false");
    }

    @Override
    public String valueToString(Object value)
    {
        return ((Boolean) value).toString();
    }

    @Override
    public Boolean valueFromString(String value)
    {
        return Boolean.parseBoolean(value);
    }

    @Override
    public void readFromJson(JsonElement element)
    {
        if (element.isJsonPrimitive())
        {
            var value = element.getAsJsonPrimitive();

            if (value.isBoolean())
            {
                this.setValueNoCallback(value.getAsBoolean());
            }
        }
    }

    @Override
    public JsonElement writeToJson()
    {
        return new JsonPrimitive(this.getValue());
    }
}

==> servux-neoforge-0.4.1%2Bmc1.21.10-sources.jar: fi/dy/masa/servux/settings/ServuxBoolSetting.java <==
package fi.dy.masa.servux.settings;

import com.google.gson.JsonElement;
import com.google.gson.JsonPrimitive;
import fi.dy.masa.servux.dataproviders.IDataProvider;
import net.minecraft.text.Text;

import java.util.List;

public class ServuxBoolSetting extends AbstractServuxSetting<Boolean>
{
    public ServuxBoolSetting(IDataProvider dataProvider, String name, Text prettyName, Text comment, boolean defaultValue, IServuxSettingCallback<Boolean> callback)
    {
        super(dataProvider, name, prettyName, comment, defaultValue, List.of("true", "false"), callback);
    }

    public ServuxBoolSetting(IDataProvider dataProvider, String name, Text prettyName, Text comment, boolean defaultValue)
    {
        super(dataProvider, name, prettyName, comment, defaultValue, List.of("true", "false"), null);
    }

    public ServuxBoolSetting(IDataProvider dataProvider, String name, boolean defaultValue, IServuxSettingCallback<Boolean> callback)
    {
        super(dataProvider, name, null, null, defaultValue, List.of("true", "false"), callback);
    }

    public ServuxBoolSetting(IDataProvider dataProvider, String name, boolean defaultValue)
    {
        super(dataProvider, name, null, null, defaultValue, List.of("true", "false"), null);
    }

    @Override
    public boolean validateString(String value)
    {
        return value.equalsIgnoreCase("true") || value.equalsIgnoreCase("false");
    }

    @Override
    public String valueToString(Object value)
    {
        return ((Boolean) value).toString();
    }

    @Override
    public Boolean valueFromString(String value)
    {
        return Boolean.parseBoolean(value);
    }

    @Override
    public void readFromJson(JsonElement element)
    {
        if (element.isJsonPrimitive())
        {
            var value = element.getAsJsonPrimitive();

            if (value.isBoolean())
            {
                this.setValueNoCallback(value.getAsBoolean());
            }
        }
    }

    @Override
    public JsonElement writeToJson()
    {
        return new JsonPrimitive(this.getValue());
    }
}
